# frozen_string_literal: true

module Hermes
  # Picture serializer
  class PictureSerializer < ActiveModel::Serializer
    cache key: proc { "#{object.cache_key}" }, expires_in: 1.day
    SIZES = %i[thumb240 thumb1000 full_size]

    attributes(SIZES + [:housing_offer_id])
    type 'pictures'

    SIZES.each do |size|
      define_method(:"#{size}_absolute") do 
        get_absolute_asset(size)
      end
      define_method(:"#{size}") do
        get_relative_asset(size)
      end
    end

    def get_absolute_asset(key)
      object["#{key}_id"] && Asset.find(object["#{key}_id"])&.sassets_url
    end 

    def get_relative_asset(key)
      object["#{key}_id"] && Asset.public_relative_url(object["#{key}_id"].to_s)
    end 

    def housing_offer_id
      object.housing_offer&.id.to_s
    end
  end
end